Discover Packages
github.com/sil-org/tfc-ops/v5
cmd
package
Version:
v5.0.0
Opens a new window with list of versions in this module.
Published: Oct 16, 2025
License: Apache-2.0
Opens a new window with license information.
Imports: 13
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
Execute adds all child commands to the root command and sets flags appropriately.
This is called by main.main(). It only needs to happen once to the rootCmd.
type Credentials struct {
Credentials struct {
AppTerraformIo struct {
Token string `json:"token"`
} `json:"app.terraform.io"`
} `json:"credentials"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.